# **BS** [![](https://gitee.com/tyoui/logo/raw/master/logo/photolog.png)][1]

## 任意进制转为任意进制
[![](https://img.shields.io/badge/个人网站-jtyoui-yellow.com.svg)][1]
[![](https://img.shields.io/badge/Python-3.6-green.svg)]()
[![](https://img.shields.io/badge/BlogWeb-Tyoui-bule.svg)][1]
[![](https://img.shields.io/badge/Email-jtyoui@qq.com-red.svg)]()
[![](https://img.shields.io/badge/项目-BS-black.svg)]()


#### 安装
    pip install jtyoui

#### 使用方法
    from jtyoui import bs
    
    if __name__ == '__main__':
        y=bs.binary_system(2542, 7, 12)#将7进制的2542转为12进制
        print(y)

***
[1]: https://blog.jtyoui.com